@@ -91,7 +91,7 @@ class PMA_Config
      *
      * @param string $source source to read config from
      */
-    function __construct($source = null)
+    public function __construct($source = null)
     {
         $this->settings = array();
 
@@ -112,9 +112,9 @@ class PMA_Config
      *
      * @return void
      */
-    function checkSystem()
+    public function checkSystem()
     {
-        $this->set('PMA_VERSION', '4.4.15.10');
+        $this->set('PMA_VERSION', '4.5.0');
         /**
          * @deprecated
          */
@@ -139,7 +139,7 @@ class PMA_Config
      *
      * @return void
      */
-    function checkOutputCompression()
+    public function checkOutputCompression()
     {
         // If zlib output compression is set in the php configuration file, no
         // output buffering should be run
@@ -160,6 +160,30 @@ class PMA_Config
         }
     }
 
+    /**
+     * Sets the client platform based on user agent
+     *
+     * @param string $user_agent the user agent
+     *
+     * @return void
+     */
+    private function _setClientPlatform($user_agent)
+    {
+        if (/*overload*/mb_strstr($user_agent, 'Win')) {
+            $this->set('PMA_USR_OS', 'Win');
+        } elseif (/*overload*/mb_strstr($user_agent, 'Mac')) {
+            $this->set('PMA_USR_OS', 'Mac');
+        } elseif (/*overload*/mb_strstr($user_agent, 'Linux')) {
+            $this->set('PMA_USR_OS', 'Linux');
+        } elseif (/*overload*/mb_strstr($user_agent, 'Unix')) {
+            $this->set('PMA_USR_OS', 'Unix');
+        } elseif (/*overload*/mb_strstr($user_agent, 'OS/2')) {
+            $this->set('PMA_USR_OS', 'OS/2');
+        } else {
+            $this->set('PMA_USR_OS', 'Other');
+        }
+    }
+
     /**
      * Determines platform (OS), browser and version of the user
      * Based on a phpBuilder article:
@@ -168,7 +192,7 @@ class PMA_Config
      *
      * @return void
      */
-    function checkClient()
+    public function checkClient()
     {
         if (PMA_getenv('HTTP_USER_AGENT')) {
             $HTTP_USER_AGENT = PMA_getenv('HTTP_USER_AGENT');
@@ -177,19 +201,7 @@ class PMA_Config
         }
 
         // 1. Platform
-        if (/*overload*/mb_strstr($HTTP_USER_AGENT, 'Win')) {
-            $this->set('PMA_USR_OS', 'Win');
-        } elseif (/*overload*/mb_strstr($HTTP_USER_AGENT, 'Mac')) {
-            $this->set('PMA_USR_OS', 'Mac');
-        } elseif (/*overload*/mb_strstr($HTTP_USER_AGENT, 'Linux')) {
-            $this->set('PMA_USR_OS', 'Linux');
-        } elseif (/*overload*/mb_strstr($HTTP_USER_AGENT, 'Unix')) {
-            $this->set('PMA_USR_OS', 'Unix');
-        } elseif (/*overload*/mb_strstr($HTTP_USER_AGENT, 'OS/2')) {
-            $this->set('PMA_USR_OS', 'OS/2');
-        } else {
-            $this->set('PMA_USR_OS', 'Other');
-        }
+        $this->_setClientPlatform($HTTP_USER_AGENT);
 
         // 2. browser and version
         // (must check everything else before Mozilla)
@@ -284,7 +296,7 @@ class PMA_Config
      *
      * @return void
      */
-    function checkGd2()
+    public function checkGd2()
     {
         if ($this->get('GD2Available') == 'yes') {
             $this->set('PMA_IS_GD2', 1);
@@ -318,7 +330,7 @@ class PMA_Config
      *
      * @return void
      */
-    function checkWebServer()
+    public function checkWebServer()
     {
         // some versions return Microsoft-IIS, some Microsoft/IIS
         // we could use a preg_match() but it's slower
@@ -337,7 +349,7 @@ class PMA_Config
      *
      * @return void
      */
-    function checkWebServerOs()
+    public function checkWebServerOs()
     {
         // Default to Unix or Equiv
         $this->set('PMA_IS_WINDOWS', 0);
@@ -358,7 +370,7 @@ class PMA_Config
      *
      * @return void
      */
-    function checkPhpVersion()
+    public function checkPhpVersion()
     {
         $match = array();
         if (! preg_match(
@@ -394,8 +406,12 @@ class PMA_Config
      *
      * @return boolean
      */
-    function isGitRevision()
+    public function isGitRevision()
     {
+        if (!$this->get('ShowGitRevision')) {
+            return false;
+        }
+
         // caching
         if (isset($_SESSION['is_git_revision'])) {
             if ($_SESSION['is_git_revision']) {
@@ -420,7 +436,7 @@ class PMA_Config
      *
      * @return void
      */
-    function checkGitRevision()
+    public function checkGitRevision()
     {
         // find out if there is a .git folder
         $git_folder = '.git';
@@ -746,22 +762,27 @@ class PMA_Config
      *
      * @return string|boolean test result or data
      */
-    function checkHTTP($link, $get_body = false)
+    public function checkHTTP($link, $get_body = false)
     {
         if (! function_exists('curl_init')) {
             return null;
         }
-        $ch = curl_init($link);
-        PMA_Util::configureCurl($ch);
-        curl_setopt($ch, CURLOPT_FOLLOWLOCATION, 0);
-        curl_setopt($ch, CURLOPT_HEADER, 1);
-        curl_setopt($ch, CURLOPT_RETURNTRANSFER, 1);
-        curl_setopt($ch, CURLOPT_CONNECTTIMEOUT, 5);
-        curl_setopt($ch, CURLOPT_TIMEOUT, 5);
+        $handle = curl_init($link);
+        if ($handle === false) {
+            return null;
+        }
+        PMA_Util::configureCurl($handle);
+        curl_setopt($handle, CURLOPT_FOLLOWLOCATION, 0);
+        curl_setopt($handle, CURLOPT_RETURNTRANSFER, 1);
+        curl_setopt($handle, CURLOPT_SSL_VERIFYHOST, 0);
+        curl_setopt($handle, CURLOPT_SSL_VERIFYPEER, 0);
+        curl_setopt($handle, CURLOPT_CONNECTTIMEOUT, 5);
+        curl_setopt($handle, CURLOPT_TIMEOUT, 5);
+        curl_setopt($handle, CURLOPT_IPRESOLVE, CURL_IPRESOLVE_V4);
         if (! defined('TESTSUITE')) {
             session_write_close();
         }
-        $data = @curl_exec($ch);
+        $data = @curl_exec($handle);
         if (! defined('TESTSUITE')) {
             ini_set('session.use_only_cookies', '0');
             ini_set('session.use_cookies', '0');
@@ -772,24 +793,13 @@ class PMA_Config
         if ($data === false) {
             return null;
         }
-        $httpOk = 'HTTP/1.1 200 OK';
-        $httpNotFound = 'HTTP/1.1 404 Not Found';
+        $http_status = curl_getinfo($handle, CURLINFO_HTTP_CODE);
 
-        if (substr($data, 0, strlen($httpOk)) === $httpOk) {
-            return $get_body
-                ? /*overload*/mb_substr(
-                    $data,
-                    /*overload*/mb_strpos($data, "\r\n\r\n") + 4
-                )
-                : true;
+        if ($http_status == 200) {
+            return $get_body ? $data : true;
         }
 
-        $httpNOK = substr(
-            $data,
-            0,
-            strlen($httpNotFound)
-        );
-        if ($httpNOK === $httpNotFound) {
+        if ($http_status == 404) {
             return false;
         }
         return null;
@@ -800,7 +810,7 @@ class PMA_Config
      *
      * @return boolean     success
      */
-    function loadDefaults()
+    public function loadDefaults()
     {
         $cfg = array();
         if (! file_exists($this->default_source)) {
@@ -830,7 +840,7 @@ class PMA_Config
      *
      * @return bool
      */
-    function load($source = null)
+    public function load($source = null)
     {
         $this->loadDefaults();
 
@@ -908,13 +918,55 @@ class PMA_Config
         return true;
     }
 
+    /**
+     * Saves the connection collation
+     *
+     * @param array $config_data configuration data from user preferences
+     *
+     * @return void
+     */
+    private function _saveConnectionCollation($config_data)
+    {
+        if (!PMA_DRIZZLE) {
+            // just to shorten the lines
+            $collation = 'collation_connection';
+            if (isset($GLOBALS[$collation])
+                && (isset($_COOKIE['pma_collation_connection'])
+                || isset($_POST[$collation]))
+            ) {
+                if ((! isset($config_data[$collation])
+                    && $GLOBALS[$collation] != 'utf8_general_ci')
+                    || isset($config_data[$collation])
+                    && $GLOBALS[$collation] != $config_data[$collation]
+                ) {
+                    $this->setUserValue(
+                        null,
+                        $collation,
+                        $GLOBALS[$collation],
+                        'utf8_general_ci'
+                    );
+                }
+            } else {
+                // read collation from settings
+                if (isset($config_data[$collation])) {
+                    $GLOBALS[$collation]
+                        = $config_data[$collation];
+                    $this->setCookie(
+                        'pma_collation_connection',
+                        $GLOBALS[$collation]
+                    );
+                }
+            }
+        }
+    }
+
     /**
      * Loads user preferences and merges them with current config
      * must be called after control connection has been established
      *
      * @return void
      */
-    function loadUserPreferences()
+    public function loadUserPreferences()
     {
         // index.php should load these settings, so that phpmyadmin.css.php
         // will have everything available in session cache
@@ -973,6 +1025,7 @@ class PMA_Config
         // in frames
 
         // save theme
+        /** @var PMA_Theme_Manager $tmanager */
         $tmanager = $_SESSION['PMA_Theme_Manager'];
         if ($tmanager->getThemeCookie() || isset($_REQUEST['set_theme'])) {
             if ((! isset($config_data['ThemeDefault'])
@@ -1024,37 +1077,7 @@ class PMA_Config
         }
 
         // save connection collation
-        if (!PMA_DRIZZLE) {
-            // just to shorten the lines
-            $collation = 'collation_connection';
-            if (isset($GLOBALS[$collation])
-                && (isset($_COOKIE['pma_collation_connection'])
-                    || isset($_POST[$collation]))
-            ) {
-                if ((! isset($config_data[$collation])
-                    && $GLOBALS[$collation] != 'utf8_general_ci')
-                    || isset($config_data[$collation])
-                    && $GLOBALS[$collation] != $config_data[$collation]
-                ) {
-                    $this->setUserValue(
-                        null,
-                        $collation,
-                        $GLOBALS[$collation],
-                        'utf8_general_ci'
-                    );
-                }
-            } else {
-                // read collation from settings
-                if (isset($config_data['collation_connection'])) {
-                    $GLOBALS['collation_connection']
-                        = $config_data['collation_connection'];
-                    $this->setCookie(
-                        'pma_collation_connection',
-                        $GLOBALS['collation_connection']
-                    );
-                }
-            }
-        }
+        $this->_saveConnectionCollation($config_data);
     }
 
     /**
@@ -1072,7 +1095,7 @@ class PMA_Config
      *
      * @return void
      */
-    function setUserValue($cookie_name, $cfg_path, $new_cfg_value,
+    public function setUserValue($cookie_name, $cfg_path, $new_cfg_value,
         $default_value = null
     ) {
         // use permanent user preferences if possible
@@ -1103,7 +1126,7 @@ class PMA_Config
      *
      * @return mixed
      */
-    function getUserValue($cookie_name, $cfg_value)
+    public function getUserValue($cookie_name, $cfg_value)
     {
         $cookie_exists = isset($_COOKIE) && !empty($_COOKIE[$cookie_name]);
         $prefs_type = $this->get('user_preferences');
@@ -1126,7 +1149,7 @@ class PMA_Config
      *
      * @return void
      */
-    function setSource($source)
+    public function setSource($source)
     {
         $this->source = trim($source);
     }
@@ -1136,7 +1159,7 @@ class PMA_Config
      *
      * @return boolean whether source is valid or not
      */
-    function checkConfigSource()
+    public function checkConfigSource()
     {
         if (! $this->getSource()) {
             // no configuration file set at all
@@ -1181,7 +1204,7 @@ class PMA_Config
      *
      * @return void
      */
-    function checkPermissions()
+    public function checkPermissions()
     {
         // Check for permissions (on platforms that support it):
         if ($this->get('CheckConfigurationPermissions')) {
@@ -1209,7 +1232,7 @@ class PMA_Config
      *
      * @return mixed value
      */
-    function get($setting)
+    public function get($setting)
     {
         if (isset($this->settings[$setting])) {
             return $this->settings[$setting];
@@ -1225,7 +1248,7 @@ class PMA_Config
      *
      * @return void
      */
-    function set($setting, $value)
+    public function set($setting, $value)
     {
         if (! isset($this->settings[$setting])
             || $this->settings[$setting] !== $value
@@ -1240,7 +1263,7 @@ class PMA_Config
      *
      * @return string  config source
      */
-    function getSource()
+    public function getSource()
     {
         return $this->source;
     }
@@ -1254,7 +1277,7 @@ class PMA_Config
      * @return int Summary of unix timestamps and fontsize,
      * to be unique on theme parameters change
      */
-    function getThemeUniqueValue()
+    public function getThemeUniqueValue()
     {
         if (null !== $this->get('fontsize')) {
             $fontsize = intval($this->get('fontsize'));
@@ -1279,7 +1302,7 @@ class PMA_Config
      *
      * @return void
      */
-    function checkPmaAbsoluteUri()
+    public function checkPmaAbsoluteUri()
     {
         // Setup a default value to let the people and lazy sysadmins work anyway,
         // they'll get an error if the autodetect code doesn't work
@@ -1347,10 +1370,12 @@ class PMA_Config
                 $pma_absolute_uri .= '@';
             }
             // Add hostname
-            $pma_absolute_uri .= urlencode($url['host']);
+            $pma_absolute_uri .= $url['host'];
             // Add port, if it not the default one
+            // (or 80 for https which is most likely a bug)
             if (! empty($url['port'])
                 && (($url['scheme'] == 'http' && $url['port'] != 80)
+                || ($url['scheme'] == 'https' && $url['port'] != 80)
                 || ($url['scheme'] == 'https' && $url['port'] != 443))
             ) {
                 $pma_absolute_uri .= ':' . $url['port'];
@@ -1432,7 +1457,7 @@ class PMA_Config
      *
      * @return String witch adjusted URI
      */
-    function getSSLUri()
+    public function getSSLUri()
     {
         // grab current URL
         $url = $this->get('PmaAbsoluteUri');
@@ -1459,7 +1484,7 @@ class PMA_Config
      *
      * @return void
      */
-    function checkCollationConnection()
+    public function checkCollationConnection()
     {
         if (! empty($_REQUEST['collation_connection'])) {
             $collation = strip_tags($_REQUEST['collation_connection']);
@@ -1476,7 +1501,7 @@ class PMA_Config
      *
      * @return void
      */
-    function checkFontsize()
+    public function checkFontsize()
     {
         $new_fontsize = '';
 
@@ -1504,7 +1529,7 @@ class PMA_Config
      *
      * @return void
      */
-    function checkUpload()
+    public function checkUpload()
     {
         if (!ini_get('file_uploads')) {
             $this->set('enable_upload', false);
@@ -1527,7 +1552,7 @@ class PMA_Config
      *
      * @return void
      */
-    function checkUploadSize()
+    public function checkUploadSize()
     {
         if (! $filesize = ini_get('upload_max_filesize')) {
             $filesize = "5M";
@@ -1578,7 +1603,7 @@ class PMA_Config
      *
      * @return bool
      */
-    function detectHttps()
+    public function detectHttps()
     {
         $url = array();
 
@@ -1633,7 +1658,7 @@ class PMA_Config
      *
      * @return void
      */
-    function checkCookiePath()
+    public function checkCookiePath()
     {
         $this->set('cookie_path', $this->getCookiePath());
     }
@@ -1663,7 +1688,7 @@ class PMA_Config
      *
      * @return void
      */
-    function enableBc()
+    public function enableBc()
     {
         $GLOBALS['cfg']             = $this->settings;
         $GLOBALS['default_server']  = $this->default_server;
@@ -1701,10 +1726,8 @@ class PMA_Config
      * @param string $current_size current selected font size with unit
      *
      * @return array selectable font sizes
-     *
-     * @static
      */
-    static protected function getFontsizeOptions($current_size = '82%')
+    protected static function getFontsizeOptions($current_size = '82%')
     {
         $unit = preg_replace('/[0-9.]*/', '', $current_size);
         $value = preg_replace('/[^0-9.]*/', '', $current_size);
@@ -1761,11 +1784,9 @@ class PMA_Config
     /**
      * returns html selectbox for font sizes
      *
-     * @static
-     *
      * @return string html selectbox
      */
-    static protected function getFontsizeSelection()
+    protected static function getFontsizeSelection()
     {
         $current_size = $GLOBALS['PMA_Config']->get('fontsize');
         // for the case when there is no config file (this is supported)
@@ -1797,11 +1818,9 @@ class PMA_Config
     /**
      * return complete font size selection form
      *
-     * @static
-     *
      * @return string html selectbox
      */
-    static public function getFontsizeForm()
+    public static function getFontsizeForm()
     {
         return '<form name="form_fontsize_selection" id="form_fontsize_selection"'
             . ' method="get" action="index.php" class="disableAjax">' . "\n"
@@ -1817,7 +1836,7 @@ class PMA_Config
      *
      * @return boolean result of setcookie()
      */
-    function removeCookie($cookie)
+    public function removeCookie($cookie)
     {
         if (defined('TESTSUITE')) {
             if (isset($_COOKIE[$cookie])) {
@@ -1847,8 +1866,8 @@ class PMA_Config
      *
      * @return boolean result of setcookie()
      */
-    function setCookie($cookie, $value, $default = null, $validity = null,
-        $httponly = true
+    public function setCookie($cookie, $value, $default = null,
+        $validity = null, $httponly = true
     ) {
         if (/*overload*/mb_strlen($value) && null !== $default && $value === $default
         ) {
@@ -1922,5 +1941,3 @@ function PMA_Config_fatalErrorHandler()
 if (!defined('TESTSUITE')) {
     register_shutdown_function('PMA_Config_fatalErrorHandler');
 }
-
-?>
